import pytest

from httmock import urlmatch, HTTMock

from util.config.validators import ConfigValidationException
from util.config.validators.validate_bitbucket_trigger import BitbucketTriggerValidator

@pytest.mark.parametrize('unvalidated_config', [
  ({}),
  ({'BITBUCKET_TRIGGER_CONFIG': {}}),
  ({'BITBUCKET_TRIGGER_CONFIG': {'CONSUMER_KEY': 'foo'}}),
  ({'BITBUCKET_TRIGGER_CONFIG': {'CONSUMER_SECRET': 'foo'}}),
])
def test_validate_invalid_bitbucket_trigger_config(unvalidated_config):
  validator = BitbucketTriggerValidator()

  with pytest.raises(ConfigValidationException):
    validator.validate(unvalidated_config, None, None)

def test_validate_bitbucket_trigger():
  url_hit = [False]

  @urlmatch(netloc=r'bitbucket.org')
  def handler(url, request):
    url_hit[0] = True
    return {
      'status_code': 200,
      'content': 'oauth_token=foo&oauth_token_secret=bar',
    }

  with HTTMock(handler):
    validator = BitbucketTriggerValidator()
    validator.validate({
      'BITBUCKET_TRIGGER_CONFIG': {
        'CONSUMER_KEY': 'foo',
        'CONSUMER_SECRET': 'bar',
      },
    }, None, None)

    assert url_hit[0]
